==> apache-qpid-broker-j-7.1.12-src.tar.gz: apache-qpid-broker-j-7.1.12-src/broker-plugins/jdbc-logging-logback/src/main/java/org/apache/qpid/server/logging/logback/jdbc/JDBCSettingsDBNameResolver.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.qpid.server.logging.logback.jdbc;

import ch.qos.logback.classic.db.names.DBNameResolver;

import org.apache.qpid.server.store.jdbc.JDBCSettings;

class JDBCSettingsDBNameResolver implements DBNameResolver
{
    private JDBCSettings _settings;

    JDBCSettingsDBNameResolver(final JDBCSettings settings)
    {
        _settings = settings;
    }

    @Override
    public <N extends Enum<?>> String getTableName(final N tableName)
    {
        final String settingsTableNamePrefix = _settings.getTableNamePrefix();
        final String prefix = settingsTableNamePrefix == null ? "" : settingsTableNamePrefix;
        final String name = prefix + tableName.toString();
        return name.toLowerCase();
    }

    @Override
    public <N extends Enum<?>> String getColumnName(final N columnName)
    {
        return columnName.toString().toLowerCase();
    }
}

==> apache-qpid-broker-j-9.2.1-src.tar.gz: apache-qpid-broker-j-9.2.1-src/broker-plugins/jdbc-logging-logback/src/main/java/org/apache/qpid/server/logging/logback/jdbc/JDBCSettingsDBNameResolver.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.qpid.server.logging.logback.jdbc;

import ch.qos.logback.classic.db.names.DBNameResolver;

import org.apache.qpid.server.store.jdbc.JDBCSettings;

class JDBCSettingsDBNameResolver implements DBNameResolver
{
    private final JDBCSettings _settings;

    JDBCSettingsDBNameResolver(final JDBCSettings settings)
    {
        _settings = settings;
    }

    @Override
    public <N extends Enum<?>> String getTableName(final N tableName)
    {
        final String settingsTableNamePrefix = _settings.getTableNamePrefix();
        final String prefix = settingsTableNamePrefix == null ? "" : settingsTableNamePrefix;
        final String name = prefix + tableName.toString();
        return name.toLowerCase();
    }

    @Override
    public <N extends Enum<?>> String getColumnName(final N columnName)
    {
        return columnName.toString().toLowerCase();
    }
}
